@@ -1,7 +1,7 @@
 /*
  The MIT License
 
- Copyright (c) 2004-2013 Paul R. Holser, Jr.
+ Copyright (c) 2004-2015 Paul R. Holser, Jr.
 
  Permission is hereby granted, free of charge, to any person obtaining
  a copy of this software and associated documentation files (the
@@ -34,14 +34,13 @@ import java.util.Date;
 import java.util.List;
 import java.util.Map;
 
-import static java.math.BigDecimal.*;
-import static java.util.Arrays.*;
-import static java.util.Collections.*;
-
 import joptsimple.util.InetAddressConverter;
 import org.junit.Before;
 import org.junit.Test;
 
+import static java.math.BigDecimal.*;
+import static java.util.Arrays.*;
+import static java.util.Collections.*;
 import static joptsimple.internal.Strings.*;
 import static joptsimple.util.DateConverter.*;
 import static org.junit.Assert.*;
@@ -64,6 +63,23 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         assertHelpLines( "No options specified  ", EMPTY );
     }
 
+    @Test
+    public void repeatedCalls() throws Exception {
+        parser.accepts( "apple" );
+
+        parser.printHelpOn( sink );
+        parser.printHelpOn( sink );
+
+        assertHelpLines(
+            "Option   Description",
+            "------   -----------",
+            "--apple             ",
+            "Option   Description",
+            "------   -----------",
+            "--apple             ",
+            EMPTY );
+    }
+
     @Test
     public void oneOptionNoArgNoDescription() throws Exception {
         parser.accepts( "apple" );
@@ -112,9 +128,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option  Description",
-            "------  -----------",
-            "-a                 ",
+            "Option       Description",
+            "------       -----------",
+            "-a <String>             ",
             EMPTY );
     }
 
@@ -138,9 +154,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option          Description        ",
-            "------          -----------        ",
-            "-a <numerical>  some value you need",
+            "Option                  Description        ",
+            "------                  -----------        ",
+            "-a <String: numerical>  some value you need",
             EMPTY );
     }
 
@@ -165,9 +181,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option       Description",
-            "------       -----------",
-            "--threshold             ",
+            "Option                Description",
+            "------                -----------",
+            "--threshold [String]             ",
             EMPTY );
     }
 
@@ -191,9 +207,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option                          Description        ",
-            "------                          -----------        ",
-            "--threshold [positive integer]  some value you need",
+            "Option                                  Description        ",
+            "------                                  -----------        ",
+            "--threshold [String: positive integer]  some value you need",
             EMPTY );
     }
 
@@ -218,9 +234,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option          Description                     ",
-            "------          -----------                     ",
-            "-W <opt=value>  Alternative form of long options",
+            "Option                  Description                     ",
+            "------                  -----------                     ",
+            "-W <String: opt=value>  Alternative form of long options",
             EMPTY );
     }
 
@@ -367,62 +383,63 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
             "Specify an embedded build script." )
             .withRequiredArg().ofType( String.class );
         parser.acceptsAll( asList( "B", "bootstrap-debug" ),
-            "Specify a text to be logged at the beginning (e.g. used by Gradle's bootstrap class." )
+            "Specify a text to be logged at the beginning (e.g. used by Gradle's bootstrap class)." )
             .withRequiredArg().ofType( String.class );
         parser.acceptsAll( asList( "h", "?" ), "Shows this help message" ).forHelp();
 
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option                        Description                           ",
-            "------                        -----------                           ",
-            "-?, -h                        Shows this help message               ",
-            "-B, --bootstrap-debug         Specify a text to be logged at the    ",
-            "                                beginning (e.g. used by Gradle's    ",
-            "                                bootstrap class.                    ",
-            "-D, --systemprop              Set system property of the JVM (e.g. -",
-            "                                Dmyprop=myvalue).                   ",
-            "-I, --no-imports              Disable usage of default imports for  ",
-            "                                build script files.                 ",
-            "-P, --projectprop             Set project property for the build    ",
-            "                                script (e.g. -Pmyprop=myvalue).     ",
-            "-S                            Don't trigger a System.exit(0) for    ",
-            "                                normal termination. Used for        ",
-            "                                Gradle's internal testing.          ",
-            "-b, --buildfile               Specifies the build file name (also   ",
-            "                                for subprojects). Defaults to build.",
-            "                                gradle.                             ",
-            "-d, --debug                   Log in debug mode (includes normal    ",
-            "                                stacktrace).                        ",
-            "-e, --embedded                Specify an embedded build script.     ",
-            "-f, --full-stacktrace         Print out the full (very verbose)     ",
-            "                                stacktrace for any exceptions.      ",
-            "-g, --gradle-user-home        Specifies the gradle user home dir.   ",
-            "-i, --ivy-quiet               Set Ivy log level to quiet.           ",
-            "-j, --ivy-debug               Set Ivy log level to debug (very      ",
-            "                                verbose).                           ",
-            "-l, --plugin-properties-file  Specifies the plugin.properties file. ",
-            "-n, --non-recursive           Do not execute primary tasks of child ",
-            "                                projects.                           ",
-            "-p, --project-dir             Specifies the start dir for Gradle.   ",
-            "                                Defaults to current dir.            ",
-            "-q, --quiet                   Log errors only.                      ",
-            "-r, --rebuild-cache           Rebuild the cache of compiled build   ",
-            "                                scripts.                            ",
-            "-s, --stacktrace              Print out the stacktrace also for user",
-            "                                exceptions (e.g. compile error).    ",
-            "-t, --tasks                   Show list of all available tasks and  ",
-            "                                their dependencies.                 ",
-            "-u, --no-search-upward        Don't search in parent folders for a  ",
-            "                                settings.gradle file.               ",
-            "-v, --version                 Print version info.                   ",
-            "-x, --cache-off               No caching of compiled build scripts. ",
+            "Option                                 Description                              ",
+            "------                                 -----------                              ",
+            "-?, -h                                 Shows this help message                  ",
+            "-B, --bootstrap-debug <String>         Specify a text to be logged at the       ",
+            "                                         beginning (e.g. used by Gradle's       ",
+            "                                         bootstrap class).                      ",
+            "-D, --systemprop <String>              Set system property of the JVM (e.g. -   ",
+            "                                         Dmyprop=myvalue).                      ",
+            "-I, --no-imports                       Disable usage of default imports for     ",
+            "                                         build script files.                    ",
+            "-P, --projectprop <String>             Set project property for the build       ",
+            "                                         script (e.g. -Pmyprop=myvalue).        ",
+            "-S                                     Don't trigger a System.exit(0) for       ",
+            "                                         normal termination. Used for Gradle's  ",
+            "                                         internal testing.                      ",
+            "-b, --buildfile <String>               Specifies the build file name (also for  ",
+            "                                         subprojects). Defaults to build.gradle.",
+            "-d, --debug                            Log in debug mode (includes normal       ",
+            "                                         stacktrace).                           ",
+            "-e, --embedded <String>                Specify an embedded build script.        ",
+            "-f, --full-stacktrace                  Print out the full (very verbose)        ",
+            "                                         stacktrace for any exceptions.         ",
+            "-g, --gradle-user-home <String>        Specifies the gradle user home dir.      ",
+            "-i, --ivy-quiet                        Set Ivy log level to quiet.              ",
+            "-j, --ivy-debug                        Set Ivy log level to debug (very         ",
+            "                                         verbose).                              ",
+            "-l, --plugin-properties-file <String>  Specifies the plugin.properties file.    ",
+            "-n, --non-recursive                    Do not execute primary tasks of child    ",
+            "                                         projects.                              ",
+            "-p, --project-dir <String>             Specifies the start dir for Gradle.      ",
+            "                                         Defaults to current dir.               ",
+            "-q, --quiet                            Log errors only.                         ",
+            "-r, --rebuild-cache                    Rebuild the cache of compiled build      ",
+            "                                         scripts.                               ",
+            "-s, --stacktrace                       Print out the stacktrace also for user   ",
+            "                                         exceptions (e.g. compile error).       ",
+            "-t, --tasks                            Show list of all available tasks and     ",
+            "                                         their dependencies.                    ",
+            "-u, --no-search-upward                 Don't search in parent folders for a     ",
+            "                                         settings.gradle file.                  ",
+            "-v, --version                          Print version info.                      ",
+            "-x, --cache-off                        No caching of compiled build scripts.    ",
             EMPTY );
     }
 
     @Test
     public void dateConverterShowsDatePattern() throws Exception {
-        parser.accepts( "date", "a date" ).withRequiredArg().withValuesConvertedBy(datePattern("MM/dd/yy"));
+        parser.accepts( "date", "a date" )
+            .withRequiredArg()
+            .withValuesConvertedBy( datePattern( "MM/dd/yy" ) );
 
         parser.printHelpOn( sink );
 
@@ -451,8 +468,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
 
     @Test
     public void inetAddressConverterShowsType() throws Exception {
-        parser.accepts( "addr", "an internet address" ).withRequiredArg()
-                .withValuesConvertedBy(new InetAddressConverter());
+        parser.accepts( "addr", "an internet address" )
+            .withRequiredArg()
+            .withValuesConvertedBy( new InetAddressConverter() );
 
         parser.printHelpOn( sink );
 
@@ -487,9 +505,9 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.printHelpOn( sink );
 
         assertHelpLines(
-            "Option  Description   ",
-            "------  -----------   ",
-            "-a      (default: boo)",
+            "Option       Description   ",
+            "------       -----------   ",
+            "-a <String>  (default: boo)",
             EMPTY );
     }
 
@@ -543,7 +561,7 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         assertHelpLines(
             "Option (* = required)  Description",
             "---------------------  -----------",
-            "* -e                              ",
+            "* -e <String>                     ",
             EMPTY );
     }
 
@@ -555,7 +573,7 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
 
         assertHelpLines(
             "Non-option arguments:",
-            "stuff                ",
+            "[String] -- stuff    ",
             EMPTY,
             "No options specified  ",
             EMPTY );
@@ -583,7 +601,7 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
 
         assertHelpLines(
             "Non-option arguments:",
-            "[files]              ",
+            "[String: files]      ",
             EMPTY,
             "No options specified  ",
             EMPTY );
@@ -639,7 +657,7 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
             public String format( Map<String, ? extends OptionDescriptor> options ) {
                 assertEquals( 1, options.size() );
                 OptionDescriptor only = options.get( "f" );
-                assertEquals( asList( "f" ), new ArrayList<String>( only.options() ) );
+                assertEquals( asList( "f" ), new ArrayList<>( only.options() ) );
                 assertFalse( only.acceptsArguments() );
                 assertEquals( "", only.argumentDescription() );
                 assertEquals( "", only.argumentTypeIndicator() );
@@ -657,6 +675,63 @@ public class DefaultSettingsOptionParserHelpTest extends AbstractOptionParserFix
         parser.formatHelpWith( null );
     }
 
+    @Test
+    public void fixForIssue56() throws Exception {
+        parser.accepts( "password", "Server Password" ).withRequiredArg().ofType( String.class );
+        parser.accepts( "F", "Forward port mapping (ie: localhost:5900:localhost:5900)" ).withRequiredArg();
+        parser.accepts( "R", "Reverse port mapping (ie: localhost:5900:localhost:5900)" ).withRequiredArg();
+
+        parser.printHelpOn( sink );
+
+        assertHelpLines(
+            "Option               Description                                             ",
+            "------               -----------                                             ",
+            "-F <String>          Forward port mapping (ie: localhost:5900:localhost:5900)",
+            "-R <String>          Reverse port mapping (ie: localhost:5900:localhost:5900)",
+            "--password <String>  Server Password                                         ",
+            EMPTY );
+    }
+
+    @Test
+    public void fixForIssue85() throws Exception {
+        parser.acceptsAll( asList( "?", "help" ), "Display this help text" ).forHelp();
+        parser.acceptsAll( asList( "c", "check-avail" ),
+            "Check Galileo homepage for available books, compare with known ones" );
+        parser.acceptsAll( asList( "d", "download-dir" ),
+            "Download directory for openbooks; must exist" )
+            .withRequiredArg().ofType( File.class ).defaultsTo( new File( "." ) );
+        parser.acceptsAll( asList( "l", "log-level" ),
+            "Log level (0=normal, 1=verbose, 2=debug, 3=trace" )
+            .withRequiredArg().ofType( int.class ).defaultsTo( 0 );
+        parser.acceptsAll( asList( "m", "check-md5" ),
+            "Download all known books without storing them, verifying their MD5 checksum (slow! >1 Gb download)" );
+        parser.acceptsAll( asList( "t", "threading" ),
+            "Threading mode (0=single, 1=multi); single is slower, but better for diagnostics)" )
+            .withRequiredArg().ofType( int.class ).defaultsTo( 1 );
+        parser.acceptsAll( asList( "w", "write-config" ),
+            "Write editable book list to config.xml, enabling you to update MD5 checksums or add new books" );
+
+        parser.printHelpOn( sink );
+
+        assertHelpLines(
+            "Option                     Description                                          ",
+            "------                     -----------                                          ",
+            "-?, --help                 Display this help text                               ",
+            "-c, --check-avail          Check Galileo homepage for available books, compare  ",
+            "                             with known ones                                    ",
+            "-d, --download-dir <File>  Download directory for openbooks; must exist         ",
+            "                             (default: .)                                       ",
+            "-l, --log-level <Integer>  Log level (0=normal, 1=verbose, 2=debug, 3=trace     ",
+            "                             (default: 0)                                       ",
+            "-m, --check-md5            Download all known books without storing them,       ",
+            "                             verifying their MD5 checksum (slow! >1 Gb download)",
+            "-t, --threading <Integer>  Threading mode (0=single, 1=multi); single is        ",
+            "                             slower, but better for diagnostics) (default: 1)   ",
+            "-w, --write-config         Write editable book list to config.xml, enabling you ",
+            "                             to update MD5 checksums or add new books           ",
+            EMPTY );
+    }
+
     private void assertHelpLines( String... expectedLines ) {
         assertEquals( join( expectedLines, LINE_SEPARATOR ), sink.toString() );
     }
